==> owncloud-10.4.0.zip: owncloud/apps/files/l10n/pl.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "Składowisko danych tymczasowo niedostępne",
    "Storage invalid" : "Pamięć nieprawidłowa",
    "Unknown error" : "Nieznany błąd",
    "All files" : "Wszystkie pliki",
    "File could not be found" : "Nie można odnaleźć pliku",
    "Home" : "Dom",
    "Close" : "Zamknij",
    "Favorites" : "Ulubione",
    "Upload timeout for file \"{file}\"" : "Przekroczony czas wysyłania pliku \"{file}\"",
    "Unknown error \"{error}\" uploading file \"{file}\"" : "Nieznany błąd \"{error}\" przy wysyłaniu pliku \"{file}\"",
    "Could not create folder \"{dir}\"" : "Nie można utworzyć folderu „{dir}”",
    "Upload cancelled." : "Wczytywanie anulowane.",
    "Processing files..." : "Przetwarzanie plików...",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Nie można przesłać {filename} być może jest katalogiem lub posiada 0 bajtów",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Brak wolnej przestrzeni, przesyłasz {size1} a pozostało tylko {size2}",
    "Target folder \"{dir}\" does not exist any more" : "Folder docelowy \"{dir}\" nie istnieje",
    "Target folder does not exist any more" : "Folder docelowy już nie istnieje",
    "Not enough free space" : "Zbyt mało wolnej pamięci",
    "Uploading..." : "Wgrywanie....",
    "..." : "...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} z {totalSize} ({bitrate})",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Wysyłanie pliku jest w toku. Jeśli opuścisz tę stronę, wysyłanie zostanie przerwane.",
    "Actions" : "Akcje",
    "Download" : "Pobierz",
    "Rename" : "Zmień nazwę",
    "Delete" : "Usuń",
    "Disconnect storage" : "Odłącz magazyn",
    "Unshare" : "Zatrzymaj współdzielenie",
    "Could not load info for file \"{file}\"" : "Nie można załadować informacji o pliku \"{file}\"",
    "Files" : "Pliki",
    "Details" : "Szczegóły",
    "Select" : "Wybierz",
    "Pending" : "Oczekujące",
    "Unable to determine date" : "Nie można ustalić daty",
    "Invalid path" : "Niewłaściwa ścieżka",
    "This operation is forbidden" : "Ta operacja jest niedozwolona",
    "This directory is unavailable, please check the logs or contact the administrator" : "Ten folder jest niedostępny, proszę sprawdzić logi lub skontaktować się z administratorem.",
    "group" : "grupa",
    "Remote share" : "Zdalny zasób",
    "Could not move \"{file}\", target exists" : "Nie można było przenieść „{file}” – plik o takiej nazwie już istnieje",
    "Could not move \"{file}\": {message}" : "Nie można przenieść \"{file}\": {message}",
    "Could not move \"{file}\"" : "Nie można było przenieść \"{file}\"",
    "{newName} already exists" : "{newName} już istnieje",
    "Could not rename \"{fileName}\", it does not exist any more" : "Nie można zmienić nazwy \"{fileName}\", plik nie istnieje",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Nazwa \"{targetName}\" jest juz używana w folderze \"{dir}\". Proszę wybrać inną nazwę.",
    "Could not rename \"{fileName}\"" : "Nie można zmienić nazwy \"{fileName}\"",
    "Could not create file \"{file}\"" : "Nie można było utworzyć pliku \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "Nie można było utworzyć pliku \"{file}\", ponieważ ten plik już istnieje.",
    "Could not create folder \"{dir}\" because it already exists" : "Nie można utworzyć folderu „{dir}”, ponieważ już istnieje.",
    "Error deleting file \"{fileName}\"." : "Błąd podczas usuwania pliku „{fileName}”.",
    "No entries in this folder match {filter}" : "Brak wyników w tym folderze pasujących do {filter}",
    "Name" : "Nazwa",
    "Size" : "Rozmiar",
    "Modified" : "Modyfikacja",
    "_%n folder_::_%n folders_" : ["%n katalog","%n katalogi","%n katalogów","%n katalogów"],
    "_%n file_::_%n files_" : ["%n plik","%n pliki","%n plików","%n plików"],
    "{dirs} and {files}" : "{dirs} i {files}",
    "You don’t have permission to upload or create files here" : "Nie masz uprawnień do wczytywania lub tworzenia plików w tym miejscu",
    "_Uploading %n file_::_Uploading %n files_" : ["Wysyłanie %n pliku","Wysyłanie %n plików","Wysyłanie %n plików","Wysyłanie %n plików"],
    "New" : "Nowy",
    "Unknown user" : "Nieznany użytkownik",
    "\"{name}\" is an invalid file name." : "\"{name}\" jest nieprawidłową nazwą pliku.",
    "File name cannot be empty." : "Nazwa pliku nie może być pusta.",
    "File name cannot contain \"/\"." : "Nazwa pliku nie może zawierać \"/\".",
    "\"{name}\" has a forbidden file type/extension." : "\"{name}\" jest zabronionym typem pliku/rozszerzeniem.",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Brak wolnego miejsca {owner}, pliki nie mogą zostać zaktualizowane lub synchronizowane! ",
    "Your storage is full, files can not be updated or synced anymore!" : "Magazyn jest pełny. Pliki nie mogą zostać zaktualizowane lub zsynchronizowane!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Miejsce dla {owner} jest na wyczerpaniu ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Twój magazyn jest prawie pełny ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["pasuje do '{filter}'","pasują do '{filter}'","pasują do '{filter}'","pasują do '{filter}'"],
    "Path" : "Ścieżka",
    "_%n byte_::_%n bytes_" : ["%n bajt","%n bajty","%n bajtów","%n bajtów"],
    "Favorited" : "Ulubione",
    "Favorite" : "Ulubione",
    "Private link:  Only people who have access to the file/folder can use it. Use it as a permanent link for yourself or to point others to files within shares" : "Prywatny link: Tylko użytkownicy, którzy mają przyznany dostęp do folderów lub plików mogą z niego skorzystać. Użyj go jako linka bezpośredniego dla siebie lub jako odnośnik dla użytkowników, którym udostępniasz.",
    "Folder" : "Folder",
    "New folder" : "Nowy folder",
    "{newname} already exists" : "{newname} już istnieje",
    "Upload" : "Wyślij",
    "An error occurred while trying to update the tags" : "Wystąpił błąd podczas aktualizacji tagów",
    "A new file or folder has been <strong>created</strong>" : "Nowy plik lub folder został <strong>utworzony</strong>",
    "A file or folder has been <strong>changed</strong>" : "Plik lub folder został <strong>zmieniony</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Ogranicz powiadomienia o utworzeniu i zmianach do swoich <strong>ulubionych plkow</strong> <em>(Tylko w strumieniu aktywności)</em>",
    "A file or folder has been <strong>deleted</strong>" : "Plik lub folder został <strong>usunięty</strong>",
    "A file or folder has been <strong>restored</strong>" : "Plik lub folder został <strong>przywrócy</strong>",
    "You created %1$s" : "Utworzyłeś %1$s",
    "%2$s created %1$s" : "%2$s utworzył %1$s",
    "%1$s was created in a public folder" : "%1$s został utworzony w folderze publicznym",
    "You changed %1$s" : "Zmieniłeś %1$s",
    "%2$s changed %1$s" : "%2$s zmienił %1$s",
    "You deleted %1$s" : "Usunąłeś %1$s",
    "%2$s deleted %1$s" : "%2$s usunął %1$s",
    "You restored %1$s" : "Przywróciłeś %1$s",
    "%2$s restored %1$s" : "%2$s przywrócił %1$s",
    "Changed by %2$s" : "Zmienione przez %2$s",
    "Deleted by %2$s" : "Usunięte przez %2$s",
    "Restored by %2$s" : "Przywrócone przez %2$s",
    "You don't have permissions to access this file/folder - Please contact the owner to share it with you." : "Nie masz uprawnień do tego pliku/katalogu - Proszę o kontakt z właścicielem udostępnianych zasobów.",
    "Upload (max. %s)" : "Wysyłka (max. %s)",
    "Settings" : "Ustawienia",
    "Show hidden files" : "Pokaż ukryte pliki",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">access your Files via WebDAV</a>" : "Użyj tego adresu aby uzyskać <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">dostęp do swoich plików poprzez WebDAV</a>",
    "No files in here" : "Brak plików",
    "Upload some content or sync with your devices!" : "Wgraj coś, albo wykonaj synchronizację ze swoimi urządzeniami.",
    "No entries found in this folder" : "Brak wpisów w tym folderze",
    "Select all" : "Wybierz wszystko",
    "Upload too large" : "Ładowany plik jest za duży",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Pliki, które próbujesz przesłać, przekraczają maksymalną dopuszczalną wielkość.",
    "No favorites" : "Brak ulubionych",
    "Files and folders you mark as favorite will show up here" : "Pliki i katalogi, które oznaczysz jako ulubione wyświetlą się tutaj",
    "Text file" : "Plik tekstowy",
    "New text file.txt" : "Nowy plik tekstowy.txt"
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");

==> owncloud-10.4.1.zip: owncloud/apps/files/l10n/pl.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "Składowisko danych tymczasowo niedostępne",
    "Storage invalid" : "Pamięć nieprawidłowa",
    "Unknown error" : "Nieznany błąd",
    "All files" : "Wszystkie pliki",
    "File could not be found" : "Nie można odnaleźć pliku",
    "Home" : "Dom",
    "Close" : "Zamknij",
    "Favorites" : "Ulubione",
    "Upload timeout for file \"{file}\"" : "Przekroczony czas wysyłania pliku \"{file}\"",
    "Unknown error \"{error}\" uploading file \"{file}\"" : "Nieznany błąd \"{error}\" przy wysyłaniu pliku \"{file}\"",
    "Could not create folder \"{dir}\"" : "Nie można utworzyć folderu „{dir}”",
    "Upload cancelled." : "Wczytywanie anulowane.",
    "The file {file} already exists" : "Plik {file} już istnieje",
    "Processing files..." : "Przetwarzanie plików...",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Nie można przesłać {filename} być może jest katalogiem lub posiada 0 bajtów",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Brak wolnej przestrzeni, przesyłasz {size1} a pozostało tylko {size2}",
    "You don’t have permission to upload or create files here" : "Nie masz uprawnień do wczytywania lub tworzenia plików w tym miejscu",
    "Target folder \"{dir}\" does not exist any more" : "Folder docelowy \"{dir}\" nie istnieje",
    "Target folder does not exist any more" : "Folder docelowy już nie istnieje",
    "The file {file} is currently locked, please try again later" : "Plik {file} jest zablokowany, spróbuj później",
    "Not enough free space" : "Zbyt mało wolnej pamięci",
    "Uploading..." : "Wgrywanie....",
    "..." : "...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} z {totalSize} ({bitrate})",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Wysyłanie pliku jest w toku. Jeśli opuścisz tę stronę, wysyłanie zostanie przerwane.",
    "Actions" : "Akcje",
    "Download" : "Pobierz",
    "Rename" : "Zmień nazwę",
    "Delete" : "Usuń",
    "Disconnect storage" : "Odłącz magazyn",
    "Unshare" : "Zatrzymaj współdzielenie",
    "Could not load info for file \"{file}\"" : "Nie można załadować informacji o pliku \"{file}\"",
    "Files" : "Pliki",
    "Details" : "Szczegóły",
    "Select" : "Wybierz",
    "Pending" : "Oczekujące",
    "Unable to determine date" : "Nie można ustalić daty",
    "Invalid path" : "Niewłaściwa ścieżka",
    "This operation is forbidden" : "Ta operacja jest niedozwolona",
    "This directory is unavailable, please check the logs or contact the administrator" : "Ten folder jest niedostępny, proszę sprawdzić logi lub skontaktować się z administratorem.",
    "group" : "grupa",
    "Remote share" : "Zdalny zasób",
    "via" : "przez",
    "Could not move \"{file}\", target exists" : "Nie można było przenieść „{file}” – plik o takiej nazwie już istnieje",
    "Could not move \"{file}\" because either the file or the target are locked." : "Nie można przenieść \"{file}\" ponieważ plik lub cel są zablokowane.",
    "Could not move \"{file}\": {message}" : "Nie można przenieść \"{file}\": {message}",
    "Could not move \"{file}\"" : "Nie można było przenieść \"{file}\"",
    "{newName} already exists" : "{newName} już istnieje",
    "Could not rename \"{fileName}\", it does not exist any more" : "Nie można zmienić nazwy \"{fileName}\", plik nie istnieje",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Nazwa \"{targetName}\" jest juz używana w folderze \"{dir}\". Proszę wybrać inną nazwę.",
    "The file \"{fileName}\" is locked and can not be renamed." : "Plik \"{fileName}\" jest zablokowany i nie można zmienić mu nazwy.",
    "Could not rename \"{fileName}\"" : "Nie można zmienić nazwy \"{fileName}\"",
    "Could not create file \"{file}\"" : "Nie można było utworzyć pliku \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "Nie można było utworzyć pliku \"{file}\", ponieważ ten plik już istnieje.",
    "Could not create folder \"{dir}\" because it already exists" : "Nie można utworzyć folderu „{dir}”, ponieważ już istnieje.",
    "The file \"{fileName}\" is locked and cannot be deleted." : "Plik \"{fileName}\" jest zablokowany i nie może być usunięty.",
    "Error deleting file \"{fileName}\"." : "Błąd podczas usuwania pliku „{fileName}”.",
    "No entries in this folder match {filter}" : "Brak wyników w tym folderze pasujących do {filter}",
    "Name" : "Nazwa",
    "Size" : "Rozmiar",
    "Modified" : "Modyfikacja",
    "_%n folder_::_%n folders_" : ["%n katalog","%n katalogi","%n katalogów","%n katalogów"],
    "_%n file_::_%n files_" : ["%n plik","%n pliki","%n plików","%n plików"],
    "{dirs} and {files}" : "{dirs} i {files}",
    "_Uploading %n file_::_Uploading %n files_" : ["Wysyłanie %n pliku","Wysyłanie %n plików","Wysyłanie %n plików","Wysyłanie %n plików"],
    "New" : "Nowy",
    "Unknown user" : "Nieznany użytkownik",
    "Lock status" : "Status blokady",
    "This resource is locked. Click to see more details." : "Ten zasób jest zablokowany. Kliknij aby zobaczyć więcej informacji.",
    "\"{name}\" is an invalid file name." : "\"{name}\" jest nieprawidłową nazwą pliku.",
    "File name cannot be empty." : "Nazwa pliku nie może być pusta.",
    "File name cannot contain \"/\"." : "Nazwa pliku nie może zawierać \"/\".",
    "\"{name}\" has a forbidden file type/extension." : "\"{name}\" jest zabronionym typem pliku/rozszerzeniem.",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Brak wolnego miejsca {owner}, pliki nie mogą zostać zaktualizowane lub synchronizowane! ",
    "Your storage is full, files can not be updated or synced anymore!" : "Magazyn jest pełny. Pliki nie mogą zostać zaktualizowane lub zsynchronizowane!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Miejsce dla {owner} jest na wyczerpaniu ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Twój magazyn jest prawie pełny ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["pasuje do '{filter}'","pasują do '{filter}'","pasują do '{filter}'","pasują do '{filter}'"],
    "{owner} has locked this resource via {path}" : "{owner} zablokował ten zasób przez {path}",
    "Could not unlock, please contact the lock owner {owner}" : "Nie można odblokować, proszę skontaktować się z blokującym {owner}",
    "Unlock failed with status {status}" : "Odblokowanie nieudane ze statusem {status}",
    "Locks" : "Blokady",
    "Resource is not locked" : "Zasób nie jest zablokowany",
    "Path" : "Ścieżka",
    "_%n byte_::_%n bytes_" : ["%n bajt","%n bajty","%n bajtów","%n bajtów"],
    "Favorited" : "Ulubione",
    "Favorite" : "Ulubione",
    "Private link:  Only people who have access to the file/folder can use it. Use it as a permanent link for yourself or to point others to files within shares" : "Prywatny link: Tylko użytkownicy, którzy mają przyznany dostęp do folderów lub plików mogą z niego skorzystać. Użyj go jako linka bezpośredniego dla siebie lub jako odnośnik dla użytkowników, którym udostępniasz.",
    "Folder" : "Folder",
    "New folder" : "Nowy folder",
    "{newname} already exists" : "{newname} już istnieje",
    "Upload" : "Wyślij",
    "An error occurred while trying to update the tags" : "Wystąpił błąd podczas aktualizacji tagów",
    "A new file or folder has been <strong>created</strong>" : "Nowy plik lub folder został <strong>utworzony</strong>",
    "A file or folder has been <strong>changed</strong>" : "Plik lub folder został <strong>zmieniony</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Ogranicz powiadomienia o utworzeniu i zmianach do swoich <strong>ulubionych plkow</strong> <em>(Tylko w strumieniu aktywności)</em>",
    "A file or folder has been <strong>deleted</strong>" : "Plik lub folder został <strong>usunięty</strong>",
    "A file or folder has been <strong>restored</strong>" : "Plik lub folder został <strong>przywrócy</strong>",
    "You created %1$s" : "Utworzyłeś %1$s",
    "%2$s created %1$s" : "%2$s utworzył %1$s",
    "%1$s was created in a public folder" : "%1$s został utworzony w folderze publicznym",
    "You changed %1$s" : "Zmieniłeś %1$s",
    "%2$s changed %1$s" : "%2$s zmienił %1$s",
    "You deleted %1$s" : "Usunąłeś %1$s",
    "%2$s deleted %1$s" : "%2$s usunął %1$s",
    "You restored %1$s" : "Przywróciłeś %1$s",
    "%2$s restored %1$s" : "%2$s przywrócił %1$s",
    "Changed by %2$s" : "Zmienione przez %2$s",
    "Deleted by %2$s" : "Usunięte przez %2$s",
    "Restored by %2$s" : "Przywrócone przez %2$s",
    "You don't have permissions to access this file/folder - Please contact the owner to share it with you." : "Nie masz uprawnień do tego pliku/katalogu - Proszę o kontakt z właścicielem udostępnianych zasobów.",
    "Upload (max. %s)" : "Wysyłka (max. %s)",
    "Settings" : "Ustawienia",
    "Show hidden files" : "Pokaż ukryte pliki",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">access your Files via WebDAV</a>" : "Użyj tego adresu aby uzyskać <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">dostęp do swoich plików poprzez WebDAV</a>",
    "No files in here" : "Brak plików",
    "Upload some content or sync with your devices!" : "Wgraj coś, albo wykonaj synchronizację ze swoimi urządzeniami.",
    "No entries found in this folder" : "Brak wpisów w tym folderze",
    "Select all" : "Wybierz wszystko",
    "Upload too large" : "Ładowany plik jest za duży",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Pliki, które próbujesz przesłać, przekraczają maksymalną dopuszczalną wielkość.",
    "No favorites" : "Brak ulubionych",
    "Files and folders you mark as favorite will show up here" : "Pliki i katalogi, które oznaczysz jako ulubione wyświetlą się tutaj",
    "Text file" : "Plik tekstowy",
    "New text file.txt" : "Nowy plik tekstowy.txt"
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
